# osh
# Copyright (C) 2005 Jack Orenstein <jao@geophile.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

import config

_clusters = {}

class Host(object):

    _name = None
    _address = None
    _db_profile = None

    def __init__(self, name, address, db_profile):
        self._name = name
        self._address = address
        self._db_profile = db_profile

    def __str__(self):
        if self._db_profile:
            return '%s(%s, %s)' % (self._name, self._address, self._db_profile)
        else:
            return '%s(%s)' % (self._name, self._address)

    name = property(lambda self: self._name)
    address = property(lambda self: self._address)
    db_profile = property(lambda self: self._db_profile)
    
class Cluster(object):

    _name = None
    _user = None
    _hosts = None

    def __init__(self, name, user, hosts):
        self._name = name
        self._user = user
        self._hosts = hosts

    def __str__(self):
        return self._name

    name = property(lambda self: self._name)
    user = property(lambda self: self._user)
    hosts = property(lambda self: self._hosts)

    def filter(self, pattern):
        return Cluster(self._name,
                       self._user,
                       [host for host in self._hosts if pattern in host.name()])
    
def cluster_named(cluster_name):
    cluster = _clusters.get(cluster_name, None)
    if cluster is None:
        config_user = config.config_value('remote', cluster_name, 'user')
        config_hosts = config.config_value('remote', cluster_name, 'hosts')
        if isinstance(config_hosts, list) or isinstance(config_hosts, tuple):
            hosts = [Host(addr, addr, None) for addr in config_hosts]
        elif isinstance(config_hosts, dict):
            hosts = []
            for name, host_spec in config_hosts.iteritems():
                addr, db_profile = _parse_host_spec(cluster_name, host_spec)
                hosts.append(Host(name, addr, db_profile))
        else:
            raise Exception(('Error in ~/.oshrc: ' +
                             'osh.remote.%s.hosts must be a list or dict') % cluster_name)
        if config_user and hosts:
            cluster = Cluster(cluster_name, config_user, hosts)
            _clusters[cluster_name] = cluster
        else:
            cluster = None
    return cluster

def _parse_host_spec(cluster_name, host_spec):
    addr = None
    db_profile = None
    if isinstance(host_spec, str):
        addr = host_spec
    elif isinstance(host_spec, dict):
        addr = host_spec.get('host', None)
        db_profile = host_spec.get('db_profile', None)
    if not addr:
        raise Exception(('Error in ~/.oshrc: ' +
                         'host specification in osh.remote.%s.hosts ' +
                         'must be string, or dict specifying keys "host" and ' +
                         'optionally "db_profile"') % cluster_name)
    return addr, db_profile
